<h1 align="center">Auvio</h1>

<p align="center">
  <a href="https://pypi.org/project/auvio/" target="_blank">
    <img alt="Auvio Logo" width="400" src="https://i.imgur.com/r2x6z2f.webp">
  </a>
</p>

Let your zuvio roll the call automatically, don’t get up for roll call anymore, give yourself a good morning.


![](https://img.shields.io/pypi/v/auvio.svg)

### Contributors

[entroy](https://github.com/entroy0421)


[Xanonymous](https://github.com/Xanonymous-GitHub)

### install
`pip3 install auvio`

### How to use
1. `from auvio import *`
2. `auvio('YOUR_ZUVIO_EMAIL@PUT.HERE', 'YOUR_ZUVIO_PASSWORD', 'CLASS_NUMBER', Latitude, longitude)`


Argument           | Type  
--------------|-------
email    | str 
password    | str
class number  | str
Latitude | float
longitude | float


3. logout will happen when user puts Ctrl + c or other KeyboardInterrupt commands
